@@ -408,7 +408,7 @@ void StatsWidget::renewCategoryView()
 						y_max = y[i]; \
 					} \
 				} \
-				this-> STAT_STRING##Curve->setData(x, y, plotSize); \
+				this-> STAT_STRING##Curve->setSamples(x, y, plotSize); \
 				this-> STAT_STRING##Plot->axisScaleEngine(QwtPlot::yLeft)->setAttribute( \
 						QwtScaleEngine::IncludeReference, \
 						this->setMinimumYValueOnPlotsToZeroCheckBox->isChecked()); \
